Class: Proscenium::Resolver

Inherits:
ActiveSupport::CurrentAttributes
  • Object
show all
Defined in:
lib/proscenium/resolver.rb

Class Method Summary collapse

Class Method Details

.resolve(path) ⇒ String

Resolve the given ‘path` to a URL path.

Parameters:

  • path (String)

    Can be URL path, file system path, or bare specifier (ie. NPM package).

Returns:

  • (String)

    URL path.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
# File 'lib/proscenium/resolver.rb', line 14

def self.resolve(path)
  self.resolved ||= {}

  self.resolved[path] ||= begin
    if path.start_with?('./', '../')
      raise ArgumentError, 'path must be an absolute file system or URL path'
    end

    if path.start_with?('proscenium/')
      "/#{path}"
    elsif (engine = Proscenium.config.engines.find { |_, v| path.start_with? "#{v}/" })
      path.sub(/^#{engine.last}/, "/#{engine.first}")
    elsif path.start_with?("#{Rails.root}/")
      path.delete_prefix Rails.root.to_s
    else
      Builder.resolve path
    end
  end
end